function [x] = seq(np,x1,n)

% Essay One - Investigation Three
% np is the number of partition of the interval (0,2)
% x1 is the initial value of the sequence
% n is the number of the terms of the sequence

t=2/np;
x(1)=x1;
for j=0:np
a=j*t;
    for i=2:n
    x(i)=1-a*x(i-1)*x(i-1);
    end
subplot(3,3,j+1)
plot(x)
end
